pub struct TaskSpec {
pub description: String,
pub priority: TaskPriority,
pub depends_on_indices: Vec<usize>,
pub agent_config: Option<TaskAgentConfig>,
}Expand description
Specification for creating a task via the convenience API.
Fields
description: StringTask description.
priority: TaskPriorityTask priority.
depends_on_indices: Vec<usize>Indices into the spec list that this task depends on.
agent_config: Option<TaskAgentConfig>Per-task agent config override (falls back to default).