Wait queue implementation for resource coordination
Manages agents waiting for locked resources with priority ordering and notification when resources become available.
Structs
- Queue
Status - Status of a wait queue for a resource
- Wait
Entry - Entry in the wait queue
- Wait
Queue - Priority-ordered wait queue for resource locks
- Wait
Queue Handle - Handle returned when registering in wait queue
- Waiter
Info - Information about a waiter in the queue
Enums
- Removal
Reason - Reason for removal from queue
- Wait
Queue Event - Events emitted by the wait queue
Functions
- file_
resource_ key - Generate a resource key for a file
- resource_
key - Generate a resource key for a given operation type and scope